@@ -88,4 +88,4 @@ class Amount(object):
 
     def exchange(self, forex_rate):
 
-        return Amount(self.value * forex_rate.value / forex_rate.weight).value
+        return Amount(self.value * forex_rate.rate / forex_rate.weight).value
