@@ -8,10 +8,10 @@ from decimal import (
 
 class ForexRate(object):
 
-    def __init__(self, base_currency, target_currency, rate):
+    def __init__(self, base_currency, target_currency, rate, origin=False):
 
-        # 汇率 = 原汇率 * 10的12次方
-        self.weight = Decimal(pow(10, 12))
+        # 汇率 = 原汇率 * 10的8次方
+        self.weight = Decimal('1') if origin else Decimal(pow(10, 8))
         # 精度，保持小数点后0位
         self.accuracy = Decimal('1')
 
@@ -46,7 +46,3 @@ class ForexRate(object):
             self.base_currency,
             rate_reversed
         )
-
-    @property
-    def value(self):
-        return self.rate
