@@ -26,8 +26,17 @@ def test_forex_rate():
 
     f2 = f1.reverse()
 
-    assert f1.value == Decimal('912000000000'), 'Error'
-    assert f2.value == Decimal('1096491228070'), 'Error'
+    assert f1.rate == Decimal('91200000'), 'Error'
+    assert f2.rate == Decimal('109649123'), 'Error'
+
+    f3 = ForexRate(
+        base_currency,
+        target_currency,
+        '912',
+        True
+    )
+
+    assert f3.rate == Decimal('912'), 'Error'
 
     m1 = Money(
         amount=320,
